@@ -32,8 +32,8 @@ unset($dbpasswd);
 $convertor_data = array(
 	'forum_name'	=> 'phpBB 2.0.x',
 	'version'		=> '1.0.3',
-	'phpbb_version'	=> '3.0.10',
-	'author'		=> '<a href="http://www.phpbb.com/">phpBB Group</a>',
+	'phpbb_version'	=> '3.0.12',
+	'author'		=> '<a href="https://www.phpbb.com/">phpBB Group</a>',
 	'dbms'			=> $dbms,
 	'dbhost'		=> $dbhost,
 	'dbport'		=> $dbport,
